<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AudioCart</name>
    <message>
        <source>Copying audio...</source>
        <translation>Kopierer lyd...</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Legg til</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Lim inn</translation>
    </message>
    <message>
        <source>WT</source>
        <translation type="obsolete">VT</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">SKILDRING</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">LENGD</translation>
    </message>
    <message>
        <source>LAST PLAYED</source>
        <translation type="obsolete">SIST SPELT</translation>
    </message>
    <message>
        <source># OF PLAYS</source>
        <translation type="obsolete">SPELT GGR</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation type="obsolete">OPPHAV</translation>
    </message>
    <message>
        <source>OUTCUE</source>
        <translation type="obsolete">UTSPOR</translation>
    </message>
    <message>
        <source>START DATE</source>
        <translation type="obsolete">STARTDATO</translation>
    </message>
    <message>
        <source>END DATE</source>
        <translation type="obsolete">SLUTTDATO</translation>
    </message>
    <message>
        <source>DAYPART START</source>
        <translation type="obsolete">DAGDEL START</translation>
    </message>
    <message>
        <source>DAYPART END</source>
        <translation type="obsolete">DAGDEL SLUTT</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="obsolete">NAMN</translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation type="obsolete">Kutt</translation>
    </message>
    <message>
        <source>Cut Info</source>
        <translation>Info om kutt</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Ta opp</translation>
    </message>
    <message>
        <source>Edit
Audio</source>
        <translation>Rediger lyd</translation>
    </message>
    <message>
        <source>Edit
Markers</source>
        <translation>Rediger
markørar</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksporter</translation>
    </message>
    <message>
        <source>Rip CD</source>
        <translation>Ripp CD</translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation>Er du sikker på at du vil sletta</translation>
    </message>
    <message>
        <source>Delete Cut</source>
        <translation>Slett kutt</translation>
    </message>
    <message>
        <source>RDCatch Event Exists</source>
        <translation>RDCatch-hending eksisterer</translation>
    </message>
    <message>
        <source>This cut is used in one or more RDCatch events!
Do you still want to delete it?</source>
        <translation type="obsolete">Dette kuttet er brukt i ei eller fleire RDCatch-hendingar.
Er du sikker på at du vil sletta det?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Tøm utklyppstavla</translation>
    </message>
    <message>
        <source>Deleting this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Viss du slettar dette kuttet, vil du òg tømma utklyppstavla.
Vil du halda fram?</translation>
    </message>
    <message>
        <source>Clipboard Empty</source>
        <translation>Tom utklyppstavle</translation>
    </message>
    <message>
        <source>Clipboard is currently empty.</source>
        <translation>Utklyppstavla er tom.</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>Lyd eksisterer</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Dette byter ut opptaket du alt har.
Vil du halda fram?</translation>
    </message>
    <message>
        <source>[new cart]</source>
        <translation>[ny korg]</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Aldri</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>1 Cut</source>
        <translation type="obsolete">1 kutt</translation>
    </message>
    <message>
        <source>RDLibrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No audio is present in the cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One or more cuts are used in one or more RDCatch events!
Do you still want to delete?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete audio for cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No data copied - you must select a single cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must select a single cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Played</source>
        <translation type="unfinished">Sist spelt</translation>
    </message>
    <message>
        <source># of Plays</source>
        <translation type="unfinished">Spelt gonger</translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ingest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outcue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daypart Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daypart End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ord</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CdRipper</name>
    <message>
        <source>Artist:</source>
        <translation>Artist:</translation>
    </message>
    <message>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <source>Other:</source>
        <translation>Anna:</translation>
    </message>
    <message>
        <source>Apply FreeDB Values to Cart</source>
        <translation>Bruk FreeDB-opplysningar på korga</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Spor</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>SPOR</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>LENGD</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TITTEL</translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation>ANNA</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TYPE</translation>
    </message>
    <message>
        <source>&amp;Rip
Track</source>
        <translation>&amp;Ripp
sporet</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normaliser</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivå:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>duMN</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autotrim</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanalar:</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>Lyd eksisterer</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Dette byter ut opptaket du alt har.
Vil du halda fram?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Tøm utklyppstavla</translation>
    </message>
    <message>
        <source>Ripping this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Viss du rippar dette sporet, tømer du utklyppstavla.
Vil du halda fram?</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Ingen tilgang</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">Greidde ikkje skriva til fila!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Audio Track</source>
        <translation>Lydspor</translation>
    </message>
    <message>
        <source>Data Track</source>
        <translation>Dataspor</translation>
    </message>
    <message>
        <source>Rip Complete</source>
        <translation type="unfinished">Ferdig å rippa</translation>
    </message>
    <message>
        <source>Rip complete!</source>
        <translation type="unfinished">Ferdig å rippa!</translation>
    </message>
    <message>
        <source>Rip Aborted</source>
        <translation type="obsolete">Avbraut rippinga</translation>
    </message>
    <message>
        <source>The rip has been aborted.</source>
        <translation type="obsolete">Rippinga er avbroten.</translation>
    </message>
    <message>
        <source>Rip Failed</source>
        <translation type="obsolete">Rippinga mislukka</translation>
    </message>
    <message>
        <source>The ripper encountered an error.
Please check your ripper configuration and try again.</source>
        <translation type="obsolete">Rippinga vart mislukka.
Sjå over innstillingane for ripping, og prøv ein gong til.</translation>
    </message>
    <message>
        <source>RDLibrary - Importer Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort
Rip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create temporary directory!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip CD</source>
        <translation type="unfinished">Ripp CD</translation>
    </message>
    <message>
        <source>Rip
Track</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DiskGauge</name>
    <message>
        <source>Free</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DiskRipper</name>
    <message>
        <source>Rip Disk</source>
        <translation>Ripp plata</translation>
    </message>
    <message>
        <source>Artist:</source>
        <translation>Artist:</translation>
    </message>
    <message>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <source>Other:</source>
        <translation>Anna:</translation>
    </message>
    <message>
        <source>Apply FreeDB Values to Carts</source>
        <translation>Bruk FreeDB-opplysningar på korgene</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Spor</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>SPOR</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>LENGD</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TITTEL</translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation>ANNA</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TYPE</translation>
    </message>
    <message>
        <source>CUT</source>
        <translation>Kutt</translation>
    </message>
    <message>
        <source>Disk Progress</source>
        <translation>Framgang for plata</translation>
    </message>
    <message>
        <source>Track Progress</source>
        <translation>Framgang for sporet</translation>
    </message>
    <message>
        <source>Set
&amp;Cut</source>
        <translation type="obsolete">Set
&amp;Kutt</translation>
    </message>
    <message>
        <source>Set All
&amp;New Carts</source>
        <translation type="obsolete">Set alle
&amp;Nye korger</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normaliser</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivå:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>duMN</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autotrim</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanalar:</translation>
    </message>
    <message>
        <source>&amp;Rip
Disk</source>
        <translation type="obsolete">&amp;Ripp
plata</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>Cut Conflict</source>
        <translation>Konflikt mellom kutt</translation>
    </message>
    <message>
        <source>That cut has already been assigned a track!</source>
        <translation>Dette kuttet er alt tildelt eit spor!</translation>
    </message>
    <message>
        <source>Cut Exists</source>
        <translation>Kuttet eksisterer</translation>
    </message>
    <message>
        <source>A recording already exists.
Do you want to overwrite it?</source>
        <translation>Det finst alt eit opptak.
Vil du byta det ut?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Tøm utklyppstavla</translation>
    </message>
    <message>
        <source>Ripping this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Viss du rippar dette kuttet, vil du òg tøma utklyppstavla.
Vil du halda fram?</translation>
    </message>
    <message>
        <source>Library Error</source>
        <translation type="obsolete">Bibliotekfeil</translation>
    </message>
    <message>
        <source>Insufficient free carts available in group!</source>
        <translation type="obsolete">Det er ikkje nok ledige korger i gruppa!</translation>
    </message>
    <message>
        <source>Audio Track</source>
        <translation>Lydspor</translation>
    </message>
    <message>
        <source>Data Track</source>
        <translation>Dataspor</translation>
    </message>
    <message>
        <source>Rip Complete</source>
        <translation>Ferdig å rippa</translation>
    </message>
    <message>
        <source>Rip complete!</source>
        <translation>Ferdig å rippa!</translation>
    </message>
    <message>
        <source>Rip Aborted</source>
        <translation type="obsolete">Avbraut rippinga</translation>
    </message>
    <message>
        <source>The rip has been aborted.</source>
        <translation type="obsolete">Rippinga er avbroten.</translation>
    </message>
    <message>
        <source>Rip Failed</source>
        <translation type="obsolete">Rippinga mislukka</translation>
    </message>
    <message>
        <source>The ripper encountered an error.
Please check your ripper configuration and try again.</source>
        <translation type="obsolete">Rippinga vart mislukka.
Sjå over innstillingane for ripping, og prøv ein gong til.</translation>
    </message>
    <message>
        <source>Total Progress</source>
        <translation type="unfinished">Framgang totalt</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Ingen tilgang</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">Greidde ikkje skriva til fila!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>&amp;Rip
Disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Importer Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort
Rip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip
Disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip aborted!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create temporary directory!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Cart
Per Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Single
Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set
&amp;Cart/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[continued]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify
Cart Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear
Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to allocate carts in group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to allocate cart in group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditCart</name>
    <message>
        <source>Number:</source>
        <translation>Nummer:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Average Length:</source>
        <translation>Snittlengd:</translation>
    </message>
    <message>
        <source>Enforce Length</source>
        <translation>Tving lengd</translation>
    </message>
    <message>
        <source>Forced Length:</source>
        <translation>Tvungen lengd:</translation>
    </message>
    <message>
        <source>Preserve Pitch</source>
        <translation>Hald tonehøgd</translation>
    </message>
    <message>
        <source>&amp;Title:</source>
        <translation>&amp;Tittel:</translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation>&amp;Startdato:</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation>Slu&amp;ttdato:</translation>
    </message>
    <message>
        <source>&amp;Artist:</source>
        <translation>&amp;Artist:</translation>
    </message>
    <message>
        <source>&amp;Year Released:</source>
        <translation>&amp;Utgjevingsår:</translation>
    </message>
    <message>
        <source>U&amp;sage:</source>
        <translation>&amp;Bruk:</translation>
    </message>
    <message>
        <source>Scheduler Codes</source>
        <translation>Planleggarkodar</translation>
    </message>
    <message>
        <source>Al&amp;bum:</source>
        <translation>A&amp;lbum:</translation>
    </message>
    <message>
        <source>Re&amp;cord Label:</source>
        <translation>&amp;Plateselskap:</translation>
    </message>
    <message>
        <source>C&amp;lient:</source>
        <translation>K&amp;lient:</translation>
    </message>
    <message>
        <source>A&amp;gency:</source>
        <translation>A&amp;gent:</translation>
    </message>
    <message>
        <source>&amp;Publisher:</source>
        <translation>Ut&amp;gjevar:</translation>
    </message>
    <message>
        <source>Compos&amp;er:</source>
        <translation>&amp;Komponist:</translation>
    </message>
    <message>
        <source>&amp;User Defined:</source>
        <translation>Br&amp;ukardefinert:</translation>
    </message>
    <message>
        <source>Schedule Cuts:</source>
        <translation type="obsolete">Planlegg kutt:</translation>
    </message>
    <message>
        <source>Execute Asynchronously</source>
        <translation>Utfør asynkront</translation>
    </message>
    <message>
        <source>&amp;Edit
Script</source>
        <translation>&amp;Rediger
skript</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>AUDIO</source>
        <translation>LYD</translation>
    </message>
    <message>
        <source>MACRO</source>
        <translation>MAKRO</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation>UKJENT</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation>TFN</translation>
    </message>
    <message>
        <source>Sequentially</source>
        <translation type="obsolete">I rekkjefylgje</translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation type="obsolete">Tilfeldig</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Missing Title</source>
        <translation>Manglar namn</translation>
    </message>
    <message>
        <source>You must provide at least a Cart Title!</source>
        <translation>Du må i alle fall skriva inn eit namn på korga!</translation>
    </message>
    <message>
        <source>Length Mismatch</source>
        <translation>Lengd passar ikkje</translation>
    </message>
    <message>
        <source>One or more cut lengths exceed the timescaling
limits of the system!  Do you still want to save?</source>
        <translation>Eitt eller fleire kutt er lenger enn det systemet
kan handtera! Vil du lagra likevel?</translation>
    </message>
    <message>
        <source>&amp;Edit
Notes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The cart title must be unique!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cond&amp;uctor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Song &amp;ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Beats per Minute:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By Specified Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By Weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schedule Cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following cut order values are assigned more than once</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Cut Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Carts [multiple]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use RDLogManager Length for PAD Updates</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMacro</name>
    <message>
        <source>Edit Macro</source>
        <translation type="obsolete">Rediger makro</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>EditNotes</name>
    <message>
        <source>Notes for cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>EditSchedulerCodes</name>
    <message>
        <source>Select Scheduler Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assigned Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ASSIGN to Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>REMOVE from Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Library Filter</source>
        <translation type="obsolete">Bibliotekfilter</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation type="obsolete">&amp;Tøm</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Avbryt</translation>
    </message>
    <message>
        <source>&amp;Filter:</source>
        <translation type="obsolete">&amp;Filter:</translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>Cart Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished">Type:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Lukk</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished">ALT</translation>
    </message>
    <message>
        <source>Cart Data Dump (CSV)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prepend Field Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MacroCart</name>
    <message>
        <source>Add</source>
        <translation>Legg til</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Lim inn</translation>
    </message>
    <message>
        <source>LINE</source>
        <translation type="obsolete">LINE</translation>
    </message>
    <message>
        <source>COMMAND</source>
        <translation type="obsolete">KOMMANDO</translation>
    </message>
    <message>
        <source>Macros</source>
        <translation>Makroar</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>Run
Line</source>
        <translation>Køyr
line</translation>
    </message>
    <message>
        <source>Run
Cart</source>
        <translation>Køyr
korg</translation>
    </message>
    <message>
        <source>--- End of cart ---</source>
        <translation type="obsolete">--- Slutten på korga ---</translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--- End of Cart ---</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>Please Wait...</source>
        <translation>Vent litt...</translation>
    </message>
    <message>
        <source>rdlibrary : </source>
        <translation type="obsolete">rdlibrary : </translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Greier ikkje kopla til</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Søk</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Tøm</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation>Planleggarkode:</translation>
    </message>
    <message>
        <source>Show Audio Carts</source>
        <translation>Vis lydkorger</translation>
    </message>
    <message>
        <source>Show Macro Carts</source>
        <translation>Vis makrokorger</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">KORG</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">GRUPPE</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">LENGD</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">TITTEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">ARTIST</translation>
    </message>
    <message>
        <source>START</source>
        <translation type="obsolete">START</translation>
    </message>
    <message>
        <source>END</source>
        <translation type="obsolete">SLUTT</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="obsolete">KLIENT</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="obsolete">AGENT</translation>
    </message>
    <message>
        <source>USER DEFINED</source>
        <translation type="obsolete">BRUKARDEFINERT</translation>
    </message>
    <message>
        <source>CUTS</source>
        <translation type="obsolete">KUTT</translation>
    </message>
    <message>
        <source>LAST CUT PLAYED</source>
        <translation type="obsolete">SISTE KUTT SPELT</translation>
    </message>
    <message>
        <source>PLAY ORDER</source>
        <translation type="obsolete">SPELEREKKJEFYLGJE</translation>
    </message>
    <message>
        <source>ENFORCE LENGTH</source>
        <translation type="obsolete">TVING LENGD</translation>
    </message>
    <message>
        <source>PRESERVE PITCH</source>
        <translation type="obsolete">HALD TONEHØGD</translation>
    </message>
    <message>
        <source>LENGTH DEVIATION</source>
        <translation type="obsolete">LENGD-FRÅVIK</translation>
    </message>
    <message>
        <source>OWNED BY</source>
        <translation type="obsolete">ÅTT AV</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>L&amp;egg til</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>&amp;Rip
CD</source>
        <translation>&amp;Ripp
CD</translation>
    </message>
    <message>
        <source>Re&amp;ports</source>
        <translation>Ra&amp;pportar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>ALT</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Are you sure you want to delete cart(s)</source>
        <translation>Er du sikker på at du vil sletta korg(ene)</translation>
    </message>
    <message>
        <source>Delete Cart(s)</source>
        <translation>Slett korg(ene)</translation>
    </message>
    <message>
        <source>Cart %06u is used in one or more RDCatch events!
Do you still want to delete it?</source>
        <translation>Korga %06u er brukt i ei eller fleire RDCatch-hendingar.
Vil du sletta ho likevel?</translation>
    </message>
    <message>
        <source>RDCatch Event Exists</source>
        <translation>RDCatch-hending eksisterer</translation>
    </message>
    <message>
        <source>Deleting cart %06u will also empty the clipboard.
      	Do you still want to proceed?</source>
        <translation>Viss du slettar korga %06u, tømer du utklyppstavla.
      	Vil du halda fram?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Tøm utklyppstavla</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation type="obsolete">Rekkjefylgje</translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="obsolete">Tilfeldig</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation>TFN</translation>
    </message>
    <message>
        <source>RDLibrary - Host:</source>
        <translation type="obsolete">RDLibrary -- Vert:</translation>
    </message>
    <message>
        <source>, User:</source>
        <translation type="obsolete">, brukar:</translation>
    </message>
    <message>
        <source>Show Note Bubbles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete audio!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Only First </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Matches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow Cart Dragging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">Slutt</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Composer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conductor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Publisher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Defined</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation type="unfinished">Kutt</translation>
    </message>
    <message>
        <source>Last Cut Played</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enforce Length</source>
        <translation type="unfinished">Tving lengd</translation>
    </message>
    <message>
        <source>Preserve Pitch</source>
        <translation type="unfinished">Hald tonehøgd</translation>
    </message>
    <message>
        <source>Length Deviation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Owned By</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Talk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run
&amp;Macro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>And Scheduler Code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matching Carts:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecordCut</name>
    <message>
        <source>RDLibrary - Record</source>
        <translation type="obsolete">RDLibrary - Opptak</translation>
    </message>
    <message>
        <source>&amp;Description</source>
        <translation>Skil&amp;dring</translation>
    </message>
    <message>
        <source>&amp;Outcue</source>
        <translation>&amp;Utspor</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation type="obsolete">Opphav</translation>
    </message>
    <message>
        <source>ISRC</source>
        <translation>ISRC</translation>
    </message>
    <message>
        <source>Weight</source>
        <translation>Vekt</translation>
    </message>
    <message>
        <source>Last Played</source>
        <translation>Sist spelt</translation>
    </message>
    <message>
        <source># of Plays</source>
        <translation>Spelt gonger</translation>
    </message>
    <message>
        <source>Cut is EVERGREEN</source>
        <translation>Kuttet er ein SLAGER</translation>
    </message>
    <message>
        <source>Air Date/Time</source>
        <translation>Påluft dato/tid</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>På</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Av</translation>
    </message>
    <message>
        <source>&amp;Start</source>
        <translation>&amp;Start</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Slutt</translation>
    </message>
    <message>
        <source>Daypart</source>
        <translation>Dagdel</translation>
    </message>
    <message>
        <source>&amp;Start Time</source>
        <translation>&amp;Starttid</translation>
    </message>
    <message>
        <source>End Time</source>
        <translation>Sluttid</translation>
    </message>
    <message>
        <source>Day of the Week</source>
        <translation>Vekedag</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Måndag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tysdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Onsdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Torsdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Fredag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Laurdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sundag</translation>
    </message>
    <message>
        <source>Set All</source>
        <translation>Set alle</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Tøm alle</translation>
    </message>
    <message>
        <source>NO SYNC!</source>
        <translation type="obsolete">INGEN SYNK!</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Kanalar</translation>
    </message>
    <message>
        <source>Record Mode</source>
        <translation>Opptaksmåte</translation>
    </message>
    <message>
        <source>AutoTrim</source>
        <translation>Autotrim</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuelt</translation>
    </message>
    <message>
        <source>VOX</source>
        <translation>VOX</translation>
    </message>
    <message>
        <source>On</source>
        <translation>På</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Av</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>Lyd eksisterer</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Dette byter ut opptaket du alt har.
Vil du halda fram?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Tøm utklyppstavla</translation>
    </message>
    <message>
        <source>This will empty the clipboard.
Do you still want to proceed?</source>
        <translation>Dette tømer utklyppstavla.
Vil du halda fram?</translation>
    </message>
    <message>
        <source>Missing Description</source>
        <translation>Manglar skildring</translation>
    </message>
    <message>
        <source>You must provide a Cut Description!</source>
        <translation>Du må skriva inn ei skildring for kuttet!</translation>
    </message>
    <message>
        <source>Invalid ISRC</source>
        <translation>Ugyldig ISRC</translation>
    </message>
    <message>
        <source>The ISRC data is malformed or invalid!</source>
        <translation>ISRC-dataa er feilforma eller ugyldige!</translation>
    </message>
    <message>
        <source>Invalid Date</source>
        <translation>Ugyldig dato</translation>
    </message>
    <message>
        <source>The Start Date is invalid!</source>
        <translation>Startdatoen er ugyldig!</translation>
    </message>
    <message>
        <source>The End Date is invalid!</source>
        <translation>Sluttdatoen er ugyldig!</translation>
    </message>
    <message>
        <source>The End Date is prior to the Start Date!</source>
        <translation>Sluttdatoen er før startdatoen!</translation>
    </message>
    <message>
        <source>The End Date has already passed!
Do you still want to save?</source>
        <translation>Sluttdatoen har allereie vore!
Vil du lagra likevel?</translation>
    </message>
    <message>
        <source>Invalid Time</source>
        <translation>Ugyldig tid</translation>
    </message>
    <message>
        <source>The Start Time is invalid!</source>
        <translation>Starttida er ugyldig!</translation>
    </message>
    <message>
        <source>The End Time is invalid!</source>
        <translation>Sluttida er ugyldig!</translation>
    </message>
    <message>
        <source>The StartTime cannot be the same as the End Time!</source>
        <translation>Starttida kan ikkje vera den same som sluttida!</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Greier ikkje kopla til</translation>
    </message>
    <message>
        <source>Unable to connect to Core AudioEngine</source>
        <translation>Greier ikkje kopla til CoreAudioEnginge</translation>
    </message>
    <message>
        <source>&amp;ISCI Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AES ALARM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ingest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Info / Record</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
